@@ -1,7 +1,7 @@
 """
 Custom exceptions for Cobbler
 
-Copyright 2006-2008, Red Hat, Inc
+Copyright 2006-2009, Red Hat, Inc
 Michael DeHaan <mdehaan@redhat.com>
 
 This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,10 @@ class CobblerException(exceptions.Exception):
    def __str__(self):
        return repr(self.value)
 
+
 class CX(CobblerException):
    pass
 
+
+class FileNotFoundException(CobblerException):
+    pass
