@@ -2,7 +2,7 @@
 Builds out filesystem trees/data based on the object tree.
 This is the code behind 'cobbler sync'.
 
-Copyright 2006-2008, Red Hat, Inc
+Copyright 2006-2009, Red Hat, Inc
 Michael DeHaan <mdehaan@redhat.com>
 
 This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,6 @@ import os
 import os.path
 import shutil
 import time
-import sub_process
 import sys
 import glob
 import traceback
@@ -61,91 +60,6 @@ class KickGen:
         self.repos       = config.repos()
         self.templar     = templar.Templar(config)
 
-    def generate_kickstart_for_profile(self,g):
-
-        g = self.api.find_profile(name=g)
-        if g is None:
-           return "# profile not found"
-
-        distro = g.get_conceptual_parent()
-        meta = utils.blender(self.api, False, g)
-        if distro is None:
-           raise CX(_("profile %(profile)s references missing distro %(distro)s") % { "profile" : g.name, "distro" : g.distro })
-        kickstart_path = utils.find_kickstart(meta["kickstart"])
-        if kickstart_path is not None and os.path.exists(kickstart_path):
-            # the input is an *actual* file, hence we have to copy it
-            try:
-                meta = utils.blender(self.api, False, g)
-                ksmeta = meta["ks_meta"]
-                del meta["ks_meta"]
-                meta.update(ksmeta) # make available at top level
-                meta["yum_repo_stanza"] = self.generate_repo_stanza(g,True)
-                meta["yum_config_stanza"] = self.generate_config_stanza(g,True)
-                meta["kickstart_done"]  = self.generate_kickstart_signal(0, g, None)
-                meta["kickstart_start"] = self.generate_kickstart_signal(1, g, None)
-                meta["kernel_options"] = utils.hash_to_string(meta["kernel_options"])
-                kfile = open(kickstart_path)
-                data = self.templar.render(kfile, meta, None, g)
-                kfile.close()
-                return data
-            except:
-                utils.log_exc(self.api.logger)
-                raise
-
-        elif kickstart_path is not None and not os.path.exists(kickstart_path):
-            if kickstart_path.find("http://") == -1 and kickstart_path.find("ftp://") == -1 and kickstart_path.find("nfs:") == -1:
-                return "# Error, cannot find %s" % kickstart_path
-        return "# kickstart is sourced externally: %s" % meta["kickstart"]
-
-    def generate_kickstart_signal(self, is_pre=0, profile=None, system=None):
-        """
-        Do things that we do at the start/end of kickstarts...
-        * start: signal the status watcher we're starting
-        * end:   signal the status watcher we're done
-        * end:   disable PXE if needed
-        * end:   save the original kickstart file for debug
-        """
-
-        nopxe = "\nwget \"http://%s/cblr/svc/op/nopxe/system/%s\" -O /dev/null"
-        saveks = "\nwget \"http://%s/cblr/svc/op/ks/%s/%s\" -O /root/cobbler.ks"
-        runpost = "\nwget \"http://%s/cblr/svc/op/trig/mode/post/%s/%s\" -O /dev/null"
-        runpre  = "\nwget \"http://%s/cblr/svc/op/trig/mode/pre/%s/%s\" -O /dev/null"
-
-        what = "profile"
-        blend_this = profile
-        if system:
-            what = "system"
-            blend_this = system
-
-        blended = utils.blender(self.api, False, blend_this)
-        kickstart = blended.get("kickstart",None)
-
-        buf = ""
-        srv = blended["http_server"]
-        if system is not None:
-            if not is_pre:
-                if str(self.settings.pxe_just_once).upper() in [ "1", "Y", "YES", "TRUE" ]:
-                    buf = buf + nopxe % (srv, system.name)
-                if kickstart and os.path.exists(kickstart):
-                    buf = buf + saveks % (srv, "system", system.name)
-                if self.settings.run_install_triggers:
-                    buf = buf + runpost % (srv, what, system.name)
-            else:
-                if self.settings.run_install_triggers:
-                    buf = buf + runpre % (srv, what, system.name)
-
-        else:
-            if not is_pre:
-                if kickstart and os.path.exists(kickstart):
-                    buf = buf + saveks % (srv, "profile", profile.name)
-                if self.settings.run_install_triggers:
-                    buf = buf + runpost % (srv, what, profile.name) 
-            else:
-                if self.settings.run_install_triggers:
-                    buf = buf + runpre % (srv, what, profile.name) 
-
-        return buf
-
     def generate_repo_stanza(self, obj, is_profile=True):
 
         """
@@ -217,43 +131,70 @@ class KickGen:
 
         return "wget \"%s\" --output-document=/etc/yum.repos.d/cobbler-config.repo\n" % (url)
 
-    def generate_kickstart_for_system(self,s):
+    def generate_kickstart_for_system(self, sys_name):
 
-
-        s = self.api.find_system(name=s)
+        s = self.api.find_system(name=sys_name)
         if s is None:
             return "# system not found"
 
-        profile = s.get_conceptual_parent()
-        if profile is None:
+        p = s.get_conceptual_parent()
+        if p is None:
             raise CX(_("system %(system)s references missing profile %(profile)s") % { "system" : s.name, "profile" : s.profile })
-        distro = profile.get_conceptual_parent()
+
+        distro = p.get_conceptual_parent()
         if distro is None: 
             # this is an image parented system, no kickstart available
             return "# image based systems do not have kickstarts"
-        meta = utils.blender(self.api, False, s)
+
+        return self.generate_kickstart(profile=p, system=s) 
+
+    def generate_kickstart(self, profile=None, system=None):
+
+        obj = system
+        if system is None:
+            obj = profile
+
+        meta = utils.blender(self.api, False, obj)
         kickstart_path = utils.find_kickstart(meta["kickstart"])
-        if kickstart_path and os.path.exists(kickstart_path):
-            try:
-                ksmeta = meta["ks_meta"]
-                del meta["ks_meta"]
-                meta.update(ksmeta) # make available at top level
-                meta["yum_repo_stanza"] = self.generate_repo_stanza(s, False)
-                meta["yum_config_stanza"] = self.generate_config_stanza(s, False)
-                meta["kickstart_done"]  = self.generate_kickstart_signal(0, profile, s)
-                meta["kickstart_start"] = self.generate_kickstart_signal(1, profile, s)
-                meta["kernel_options"] = utils.hash_to_string(meta["kernel_options"])
-                kfile = open(kickstart_path)
-                data = self.templar.render(kfile, meta, None, s)
-                kfile.close()
-                return data
-            except:
-                traceback.print_exc()
-                raise CX(_("Error templating file"))
-        elif kickstart_path is not None and not os.path.exists(kickstart_path):
-            if kickstart_path.find("http://") == -1 and kickstart_path.find("ftp://") == -1 and kickstart_path.find("nfs:") == -1:
-                return "# Error, cannot find %s" % kickstart_path
-        return "# kickstart is sourced externally: %s" % meta["kickstart"]
 
+        if not kickstart_path:
+            return "# kickstart is missing or invalid: %s" % meta["kickstart"]
 
+        ksmeta = meta["ks_meta"]
+        del meta["ks_meta"]
+        meta.update(ksmeta) # make available at top level
+        meta["yum_repo_stanza"] = self.generate_repo_stanza(obj, (system is None))
+        meta["yum_config_stanza"] = self.generate_config_stanza(obj, (system is None))
+        meta["kernel_options"] = utils.hash_to_string(meta["kernel_options"])
+        # meta["config_template_files"] = self.generate_template_files_stanza(g, False)
 
+        try:
+            raw_data = utils.read_file_contents(kickstart_path, self.api.logger,
+                    self.settings.template_remote_kickstarts)
+            if raw_data is None:
+                return "# kickstart is sourced externally: %s" % meta["kickstart"]
+            data = self.templar.render(raw_data, meta, None, obj)
+            return data
+        except FileNotFoundException:
+            self.api.logger.warning("kickstart not found: %s" % meta["kickstart"])
+            return "# kickstart not found: %s" % meta["kickstart"]
+
+    def generate_kickstart_for_profile(self,g):
+
+        g = self.api.find_profile(name=g)
+        if g is None:
+           return "# profile not found"
+
+        distro = g.get_conceptual_parent()
+        if distro is None:
+           raise CX(_("profile %(profile)s references missing distro %(distro)s") % 
+                   { "profile" : g.name, "distro" : g.distro })
+
+        return self.generate_kickstart(profile=g)
+
+    def get_last_errors(self):
+        """
+        Returns the list of errors generated by 
+        the last template render action
+        """
+        return self.templar.last_errors
